@@ -10,9 +10,12 @@ from urllib.error import URLError
 
 
 def convert2rst():
+
     long_description = None
+
     import pypandoc
     from pypandoc.pandoc_download import download_pandoc
+
     # see the documentation how to customize the installation path
     # but be aware that you then need to include it in the `PATH`
     try:
@@ -20,8 +23,14 @@ def convert2rst():
         os.system('dpkg -x ./$(ls pandoc*.deb|head -1) pandoc_bin')
     except URLError:
         logging.warning(traceback.format_exc())
-    #: convert -> rst
-    os.system('./pandoc_bin/usr/bin/pandoc -s README.md -t rst -o README.rst~')
+    finally:
+        #: convert -> rst
+        if os.path.exists('./pandoc_bin/'):
+            os.system('./pandoc_bin/usr/bin/pandoc -s README.md -t rst -o README.rst~')
+        else:
+            os.system('pandoc -s README.md -t rst -o README.rst~')
+
+    #: replace the description in the RST version
     with open('README.rst~', 'r') as f:
         long_description = f.read()
     pattern = re.compile(
@@ -33,7 +42,7 @@ def convert2rst():
         f.write(long_description)
     os.system('rm README.rst~')
     print('...done with fix_readme.py')
-
+    return True
 
 if __name__ == '__main__':
     convert2rst()
